# 🤖 AI Code Review Tool for GitHub

## 📝 License

Licensed under the [MIT License](https://github.com/Nayjest/github-ai-code-review/blob/main/LICENSE)
© 2025 [Vitalii Stepanenko](mailto:mail@vitaliy.in)